% for workorder in report.workorders:
${ _("Client") }: | ${ workorder.client.person.name } | ${ _("Work order") }: | ${ workorder.identifier }
${ _("Responsible") }: % if workorder.quote_responsible: | ${ workorder.quote_responsible.get_description() } % else: | % endif | ${ _("Open Date") }: | ${ format_date(workorder.open_date) }
|  | ${ _("Estimated finish") }: | ${ format_date(workorder.estimated_finish) }
% endfor
% if workorder.sellable:
${ _("Equipment") }: | ${ workorder.sellable.description }
% endif
${ _("Description") }: | ${ workorder.description }

% if workorder.defect_reported:

${ _("Defect reported by client:") } % for line in workorder.defect_reported.split("\n"): ${ line | h }
% endfor

% endif